SubLasso <- function(X, y, subset, nfold)
{
    xnames <- row.names(X)
    if (is.null(xnames)) {
        xnames <- paste0("P", 1:nrow(X))
    }
    if (!missing(subset)) {
        jd <- match(subset, xnames, 0)
        if (!all(jd > 0))
        stop(paste(subset[which(jd==0)],"out of range, please check it!"))
    } else {
        jd <- as.integer(0)
    }
    if (missing(nfold)) {
        nfold <- 5
    }
    x <- t(X)
    n <- nrow(x)
    p <- ncol(x)
    fact <- rep(1, p)
    fact[jd] <- 0
    x <- as.matrix(x)
    options(warn = -1)
    cv.fit <- cv.glmnet(x, y, family = "binomial", nfolds = length(y))
    lambda <- cv.fit$lambda.min
    fit <- glmnet(x, y, family = "binomial", penalty.factor = fact)
    predp <- predict(fit, x, s = cv.fit$lambda.min, type = "response")
    Coef <- coef(fit, s = lambda)[-1]
    intercept<- coef(fit, s = lambda)[1]
    Active.Index <- which(Coef != 0)
    Active.Index.num <- length(Active.Index)
    if (Active.Index.num == 0) {
        sumCoef <- apply(as.matrix(cv.fit$glmnet.fit$beta), 2,
        function(x) sum((x != 0)))
        newCut <- which.max(sumCoef >= 1)
        Active.Index <- which(as.matrix(cv.fit$glmnet.fit$beta)[,
        newCut] != 0)
        Active.Index.num <- length(Active.Index)
    }
    Active.Coef <- Coef[Active.Index]
    newdata <- cbind(y, x[, Active.Index])
    num_tp <- num_fp <- num_fn <- num_tn <- NULL
    Sn <- Sp <- Acc <- Mcc <- NULL
    cv.predp <- cv.predy <- NULL
    set.seed(1010)
    id <- sample(1:nfold, nrow(newdata), replace = TRUE)
    for (i in 1:nfold) {
        y_train <- newdata[id != i, 1]
        y_test <- newdata[id == i, 1]
        x_train <- matrix(newdata[id != i, -1], ncol = Active.Index.num)
        x_test <- matrix(newdata[id == i, -1], ncol = Active.Index.num)
        cv.fit.train <- cv.glmnet(x_train, y_train, family = "binomial")
        fit.train <- glmnet(x_train, y_train, family = "binomial")
        cv.predp[which(id == i)] <- predict(fit.train, x_test,
        s = cv.fit.train$lambda.min, type = "response")
    }
    cv.predy <- ifelse(cv.predp > 0.5, 1, 0)
    num_tp <- sum(y == 1 & cv.predy == 1)
    num_fn <- sum(y == 1 & cv.predy == 0)
    num_fp <- sum(y == 0 & cv.predy == 1)
    num_tn <- sum(y == 0 & cv.predy == 0)
    Sn <- num_tp/sum(y == 1)
    Sp <- num_tn/sum(y == 0)
    Acc <- (num_tp + num_tn)/n
    Mcc <- (num_tp * num_tn - num_fp * num_fn)/(sqrt((num_tp +
    num_fp) * (num_tp + num_fn) * (num_tn + num_fp) * (num_tn +
    num_fn)))
    valid <- cbind(Sn, Sp, Acc, Mcc)
    color.map <- function(mol.biol) {
        if (mol.biol == 0)
        "#FF0000"
        else {
            if (mol.biol == 1)
            "#000FFF"
            else "#F000FF"
        }
    }
    patientcolors <- unlist(lapply(y, color.map))
    show.heatmap <- function() {
        heatmap.2(t(x[, Active.Index]), col = redgreen(75), scale = "row",
        ColSideColors = patientcolors, key = TRUE, symkey = FALSE,
        density.info = "none", trace = "none", cexRow = 0.7)
    }
    description <- describeBy(x[, Active.Index], y)
    correlation <- cor(x[, Active.Index])
    show.boxplot <- function() {
        boxplot(predp ~ y, col = "gold", xlab = "Group", ylab = "Linear predictor")
    }
    l <- list(selname = xnames[Active.Index], nfold = nfold,
    valid = valid, description = description, correlation = correlation,
    w = Active.Coef, intercept=intercept, lambda = lambda, cv.predp = cv.predp,
    cv.predy = cv.predy, show.heatmap = show.heatmap, show.boxplot = show.boxplot,
    fit = fit)
    class(l) <- "SubLasso"
    return(l)
}
