\name{SubLasso}
\alias{SubLasso}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Gene selection using Lasso for gene expression profile matrix with user-defined genes fixed in model.
}
\description{
This package implemented a feature selection procedure with the optimized classification accuracy, and the chosen feature subset consists of the user-defined seed features. For the convenience of the users, the k-fold cross validation performance will also be calculated. The other user-friendly assets of this package include the minimum requirement for the parameter tuning, by automatic optimization.
}
\usage{
SubLasso(X, y, subset, nfold)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{X}{The gene expression matrix, row is sample, column is for the expression levels of genes (probe sets).}
  \item{y}{The category vector, 1 (positive, illness) or 0 (negative, normal).}
  \item{subset}{The vector of gene names (probe sets) must belong to the genes in the model. Default is null set, meaning no pre-fixed genes.}
  \item{nfold}{The number of cross-validation. Default is 5.}
}
\value{
%%  ~Describe the value returned
%%  If it is a LIST, use
%%  \item{comp1 }{Description of 'comp1'}
%%  \item{comp2 }{Description of 'comp2'}
%% ...
\item{selname}{The vector of features selected by the model.}
\item{valid}{ The performance measurements sensitivity (Sn), specificity (Sp), Accuracy (Acc), and Matthews correlation coefficient (Mcc).}
\item{description}{A descriptive summarization of selected features.}
\item{correlation}{The correlations among the selected features.}
\item{w}{The coefficient (weight) of each feature in the model.}
\item{lambda}{The actual penalty parameter values used or optimized.}
\item{cv.predp}{The predict probability in cross-validation.}
\item{cv.predy}{The predict class label in cross-validation.}
\item{fit}{The fitted model when doing feature selection.}
\item{show.boxplot}{A boxplot produced by the linear prediction function of logisitic model. X-axis is the sample group and Y-axis is the prediction function score of each subject. The up and down real line of box is the 0.75 and 0.25 quantile respectively. The bold real line in the middle of box is the median.}
\item{show.heatmap}{The hierarchical clustering of samples based on expression patterns of the selected features. Each row corresponds to a feature and each column corresponds to a sample. The status of illness or normal for each subject is shown with the above bar. Gene expression value is indicated by different color in the medial matrix.}
}
\references{
%% ~put references to the literature/web site here ~
[1] Friedman, J., Hastie, T. and Tibshirani, R. (2008) Regularization Paths for Generalized Linear Modelsvia Coordinate Descent, http://www.stanford.edu/~hastie/Papers/glmnet.pdf Journal of Statistical Software, Vol. 33(1), 1-22 Feb 2010. http://www.jstatsoft.org/v33/i01/\cr
[2] Simon, N., Friedman, J., Hastie, T., Tibshirani, R. (2011) Regularization Paths for Cox's Proportional Hazards Model via Coordinate Descent, Journal of Statistical Software, Vol. 39(5) 1-13 http://www.jstatsoft.org/v39/i05/


}
\author{
%%  ~~who you are~~
Youxi Luo, Qinghan Meng, Ruiquan Ge, Guoqin Mai, Jikui Liu, Fengfeng Zhou(#corresponding)
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
glmnet
} \examples{ 
##### Example 1
library(SubLasso)
data(Golub_Merge)
X <- Golub_Merge$X
y <- Golub_Merge$y
f1=SubLasso(X,y,nfold=10)
## The linear discriminating function
cat(f1$intercept, " + ", paste(f1$w,f1$selname,collapse=" + ",sep="*"))


## predict.SubLasso(f1,X[1:10,]) ##error predicted x
predy=predict.SubLasso(f1,X)
predy=predict.SubLasso(f1,X,type="class")
predy=predict.SubLasso(f1,X,type="link")
predy=predict.SubLasso(f1,X,type="response")
predy=predict.SubLasso(f1,X,type="response",s=0.05)
subset=f1$selname
f2=SubLasso(X,y,subset,nfold=10)
cat(f2$intercept, " + ", paste(f2$w,f2$selname,collapse=" + ",sep="*"))
f2$show.boxplot()
f2$show.heatmap()

subset=row.names(X)[1:10]
f3=SubLasso(X,y,subset,nfold=10)
predy=predict.SubLasso(f3,X)
predy=predict.SubLasso(f3,X,type="class")
predy=predict.SubLasso(f3,X,type="link")
predy=predict.SubLasso(f3,X,type="response")
predy=predict.SubLasso(f3,X,type="response",s=0.05)
cat(f3$intercept, " + ", paste(f3$w,f3$selname,collapse=" + ",sep="*"))
f3$show.heatmap()

###Example 2
library(SubLasso)
data(Colon)
X<-Colon$X
y<-ifelse(Colon$y == 1,1,0)
f1=SubLasso(X,y,nfold=10)
subset=f1$selname
## The linear discriminating function
cat(f1$intercept, " + ", paste(f1$w,f1$selname,collapse=" + ",sep="*"))

f2=SubLasso(X,y,subset,nfold=10)
subset=row.names(X)[30:40]
cat(f2$intercept, " + ", paste(f2$w,f1$selname,collapse=" + ",sep="*"))

f3=SubLasso(X,y,subset,nfold=10)
cat(f3$intercept, " + ", paste(f3$w,f1$selname,collapse=" + ",sep="*"))
f3$show.boxplot()
f3$show.heatmap()

% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
}
